import alg_names, DataLoader, settings
import numpy as np
import copy
import matplotlib.pyplot as plt
from matplotlib import rc, mlab
from matplotlib import font_manager

rc('font',**{'family':'sans-serif','sans-serif':['Helvetica']})
rc('text', usetex=True)


"""
Class for plotting outputs of experiments. This only makes comparison type
plots. For other types see PlotThresholds.py
"""
class PlotComparison(object):
    
    def __init__(self, type, params={}):
        """
        Initialize a PlotComparison object. Given a experiment type load the raw
        data for that type.
        """
        self.type = type
        self.dl = DataLoader(self.type)
        self.dl.read_data(params=params)
        self.params = copy.deepcopy(params)
    
    def plot_lines(self):
        """
        Plot the data and save the figure to the settings.FIGDIR directory
        """
        assert len(self.dl.data) == len(alg_names.HIERARCHICAL_ALGORITHMS)
        fig = plt.figure(figsize=(24,13))
        ax1 = fig.add_subplot(111)

        ls = []
        for i in range(len(alg_names.HIERARCHICAL_ALGORITHMS)):
            l = ax1.plot(self.dl.xaxis, self.dl.data[i][0])
            plt.setp(l, linewidth=5, marker=".", markersize=30)
            ls.append(l)
        plt.legend(ls, [alg().shortname for alg in alg_names.HIERARCHICAL_ALGORITHMS], numpoints=2, handlelen=0.1, prop = font_manager.FontProperties(size=50), loc=2)
        ax1.set_xlabel(self.dl.xlabel, fontsize=50)
        ax1.set_ylabel(self.type, fontsize=50)
        for tick in ax1.xaxis.get_major_ticks():
            tick.label1.set_fontsize(40)
        for tick in ax1.yaxis.get_major_ticks():
            tick.label1.set_fontsize(40)
        fname = settings.FIGDIR+"%s" % (self.type)
        if 'n' in self.params.key():
            fname += '_n=%s' % (self.params['n'])
        if 'matrix' in self.params.keys():
            fname += '_%s' % (self.params['matrix'])
        fname += ".eps"
        plt.show()
        plt.savefig(fname, dpi=2000, format='eps')

